% define velocity model: compare 2 sets of grids

% first set of grid
z1 = 0:10:1000;
x1 = 0:10:1000;
[o1,d1,n1] = grid2odn(z1,x1);
[zz1,xx1] = ndgrid(z1,x1);

% second set of grid
z2 = 0:5:1000;
x2 = 0:5:1000;% x2 is different from x1
[o2,d2,n2] = grid2odn(z2,x2);
[zz2,xx2] = ndgrid(z2,x2);

% background velocity 2500 [m/s]
v1 = 2500 + 0*xx1;
v2 = 2500 + 0*xx2;

% plot model
figure
subplot 121
imagesc(x1,z1,v1);xlabel('x [m]');ylabel('z [m]');title('velocity defined on the first set of grid [m/s]');colorbar;

subplot 122
imagesc(x2,z2,v2);xlabel('x [m]');ylabel('z [m]');title('velocity defined on the second set of grid [m/s]');colorbar;
%% setup modeling parameters for reflection experiment
% grid
model_r1.o = o1; 
model_r1.d = d1;
model_r1.n = n1;

% number of points for absorbing boundary
model_r1.nb = [20 20];

% single frequency
model_r1.freq = 10; 

% Ricker wavelet with peak frequency f0 and phase shift t0
model_r1.f0 = 10;
model_r1.t0 = 0;

% source and receiver locations
model_r1.zsrc = 10;
model_r1.xsrc = 500; 

model_r1.zrec = 20;
model_r1.xrec = 0:10:1000;  

% define the second model on grid 2
model_r2=model_r1;
model_r2.o = o2; 
model_r2.d = d2;
model_r2.n = n2;

% source matrix, each column is a source function defined on the source
Q = speye(1);% a single source
m1 = 1e6./v1(:).^2;% squared slowness [km^2/s^2]
m2 = 1e6./v2(:).^2;% squared slowness [km^2/s^2]

% create data
D1 = F(m1,Q,model_r1);
D2 = F(m2,Q,model_r2);

% create data with pre-scaled source
%D1 = F(m1,Q/prod(model_r1.d),model_r1);
%D2 = F(m2,Q/prod(model_r2.d),model_r2);

%% display wavefield data
figure
hold on
plot(model_r1.xrec, abs(D1))
plot(model_r2.xrec, abs(D2))
legend('data from first grid','data from second grid')
xlabel('x [m]')
ylabel('Amplitude')



